Learn R Programming

hit (version 0.2-2)

fast.glmanova: Fast GLM F test of LR test ANOVA

Description

A fast sequential analysis of variance (ANOVA). Mainly developed for internal use.

Usage

fast.glmanova(x, y, assign, family, test)

Arguments

x
Design matrix of dimension n * p.
y
Response vector of observations of length n.
assign
Integer vector assigning columns to terms.
family
A description of the error distribution and link function to be used in the model. For glm this must be the result of a call to a family function.
test
The name of the test either "LRT" (default) for likelihood ratio test or "F" for F test.