Learn R Programming

hit (version 0.2-0)

reorder.hierarchy: Reorder Hierarchy

Description

Reorder indexes according to a vector of names.

Usage

## S3 method for class 'hierarchy':
reorder(x, names, ...)

Arguments

names
Variable names in the order in which the indexes shut be given to the variables.
...
Further arguments passed to or from other methods (not used).