Learn R Programming

hit (version 0.3.1)

reorder.hierarchy: Reorder Hierarchy

Description

Reorder indexes according to a vector of names.

Usage

"reorder"(x, names, ...)

Arguments

names
Variable names in the order in which the indexes should be assigned to the variables.
...
Further arguments passed to or from other methods (not used).