Usage
samp1.lasso(samp1, x, y, family, penalty.factor, sel.method, act.freq, nfolds,
lambda.opt, n.samp2, ...)
Arguments
samp1
List of index for subsample (mclapply index).
x
Design matrix, of dimension n x p.
y
Vector of quantitative response variable.
family
Distribution family of y.
penalty.factor
See glmnet.
sel.method
Name of method for the selection of covariates via the
LASSO, either "AF" (default), the occurrence frequenze of covariates along
the lambda path or "CV" n-fold cross-validation.
act.freq
Frequency in which a covariate has to occur along the
lambda path to be selected in the active set. Ignored if sel.method
is "CV".
nfolds
Number of folds (default is 10). Ignored if sel.method
is "ASF". See cv.glmnet for more details. lambda.opt
Criterion for optimum selection of cross validated lasso.
Either "lambda.1se" (default) or "lambda.min". Ignored if sel.method
is "ASF". See cv.glmnet for more details. n.samp2
Number of individuals in samp2 which is the max.
for non zero coefficients.