Rdocumentation
powered by
Learn R Programming
hit (version 0.3.1)
samp1.lasso: Variabel Screening
Description
LASSO function of the HIT algorithem.
Usage
samp1.lasso(samp1, x, y, family, alpha, lambda, penalty.factor, n.samp2, ...)
Arguments
samp1
List of index for subsample (mclapply index).
x
Design matrix, of dimension n x p.
y
Vector of quantitative response variable.
family
Distribution family of
y
.
alpha
Mixing value for elnet.
lambda
A vector of lambda values sorted from large to small where the smallest is the optimal value.
penalty.factor
See glmnet.
n.samp2
Number of individuals in samp2 which is the max. for non zero coefficients.
...
Additional agruments.